@@ -85,15 +85,17 @@ def main(model, checkpoint=None):
         Parameters.pin_memory,
     )
 
-    scaler = torch.cuda.amp.GradScaler()
     min_loss = float('inf')
+    scaler = torch.cuda.amp.GradScaler()
     patience = Parameters.patience
+    loss_fn = Parameters.loss_fn
+    device = Parameters.device
 
     for epoch in range(Parameters.max_epoch):
-        train_fn(train_loader, model, optimizer, Parameters.loss_fn, scaler)
+        train_fn(train_loader, model, optimizer, loss_fn, scaler, device)
 
         # check kldiv
-        loss = check_loss(val_loader, model, Parameters.loss_fn, device=Parameters.device)
+        loss = check_loss(val_loader, model, loss_fn, device=device)
 
         # early stop
         if loss < min_loss:
